searchData={"items":[{"type":"module","title":"OpentelemetryPhoenix","doc":"OpentelemetryPhoenix uses [telemetry](https://hexdocs.pm/telemetry/) handlers to create `OpenTelemetry` spans.\n\nCurrent events which are supported include endpoint start/stop, router start/stop,\nand router exceptions.","ref":"OpentelemetryPhoenix.html"},{"type":"module","title":"Supported options - OpentelemetryPhoenix","doc":"* `:endpoint_prefix` (list of `t:atom/0`) - The endpoint prefix in your endpoint. The default value is `[:phoenix, :endpoint]`.\n\n* `:adapter` (:atom) - Required. The phoenix server adapter being used. The default value is `:cowboy2`.\n\n* `:liveview` (`t:boolean/0`) - Whether LiveView traces will be instrumented. The default value is `true`.\n\n\n\n#### Adapters\n\n* `cowboy2` - when using PlugCowboy as your adapter you must add `:opentelemetry_cowboy` to your project\nand pass `adapter: :cowboy2` option when calling setup.\n* `bandit` - when using `Bandit.PhoenixAdapter` as your adapter you must add `:opentelemetry_bandit` to your project\nand pass `adapter: :bandit` option when calling setup","ref":"OpentelemetryPhoenix.html#module-supported-options"},{"type":"module","title":"Usage - OpentelemetryPhoenix","doc":"In your application start:\n\n    def start(_type, _args) do\n      :opentelemetry_cowboy.setup()\n      OpentelemetryPhoenix.setup(adapter: :cowboy2)\n\n      children = [\n        {Phoenix.PubSub, name: MyApp.PubSub},\n        MyAppWeb.Endpoint\n      ]\n\n      opts = [strategy: :one_for_one, name: MyStore.Supervisor]\n      Supervisor.start_link(children, opts)\n    end","ref":"OpentelemetryPhoenix.html#module-usage"},{"type":"type","title":"OpentelemetryPhoenix.adapter/0","doc":"The phoenix server adapter being used. Required","ref":"OpentelemetryPhoenix.html#t:adapter/0"},{"type":"function","title":"OpentelemetryPhoenix.attach_liveview_handlers/0","doc":"","ref":"OpentelemetryPhoenix.html#attach_liveview_handlers/0"},{"type":"type","title":"OpentelemetryPhoenix.endpoint_prefix/0","doc":"The endpoint prefix in your endpoint. Defaults to `[:phoenix, :endpoint]`","ref":"OpentelemetryPhoenix.html#t:endpoint_prefix/0"},{"type":"function","title":"OpentelemetryPhoenix.handle_liveview_event/4","doc":"","ref":"OpentelemetryPhoenix.html#handle_liveview_event/4"},{"type":"type","title":"OpentelemetryPhoenix.liveview/0","doc":"Attach LiveView handlers. Optional","ref":"OpentelemetryPhoenix.html#t:liveview/0"},{"type":"type","title":"OpentelemetryPhoenix.opts/0","doc":"Setup options","ref":"OpentelemetryPhoenix.html#t:opts/0"},{"type":"function","title":"OpentelemetryPhoenix.setup/1","doc":"Initializes and configures the telemetry handlers.","ref":"OpentelemetryPhoenix.html#setup/1"},{"type":"extras","title":"OpentelemetryPhoenix","doc":"# OpentelemetryPhoenix\n\n[![EEF Observability WG project](https://img.shields.io/badge/EEF-Observability-black)](https://github.com/erlef/eef-observability-wg)\n[![Hex.pm](https://img.shields.io/hexpm/v/opentelemetry_phoenix)](https://hex.pm/packages/opentelemetry_phoenix)\n![Build Status](https://github.com/opentelemetry-beam/opentelemetry_phoenix/workflows/Tests/badge.svg)\n\nTelemetry handler that creates Opentelemetry spans from Phoenix events.\n\nAfter installing, setup the handler in your application behaviour before your\ntop-level supervisor starts.\n\n```elixir\nOpentelemetryPhoenix.setup(adapter: :bandit)\n```\n\nSee the documentation for `OpentelemetryPhoenix.setup/1` for additional options that\nmay be supplied.","ref":"readme.html"},{"type":"extras","title":"Installation - OpentelemetryPhoenix","doc":"```elixir\ndef deps do\n  [\n    {:opentelemetry_phoenix, \"~> 2.0.0-rc.2\"}\n  ]\nend\n```\n\n[OpentelemetryBandit](https://hex.pm/packages/opentelemetry_bandit) or [OpentelemetryCowboy](https://hex.pm/packages/opentelemetry_cowboy) must be installed to capture the full\nrequest lifecycle. Phoenix only handles part of the request lifecycle which can lead\nto incomplete request durations and lost traces for requests terminated at the socket\nlevel or before reaching Phoenix.","ref":"readme.html#installation"},{"type":"extras","title":"Note on Phoenix integration - OpentelemetryPhoenix","doc":"`OpentelemetryPhoenix` requires phoenix to use `Plug.Telemetry` in order to correctly trace endpoint calls.\n\nThe `endpoint.ex` file should look like:\n\n```Elixir\ndefmodule MyApp.Endpoint do\n  use Phoenix.Endpoint, otp_app: :my_app\n  ...\n  plug Plug.Telemetry, event_prefix: [:phoenix, :endpoint]\n  ...\nend\n```\n\nThe [Phoenix endpoint.ex template](https://github.com/phoenixframework/phoenix/blob/v1.6.0/installer/templates/phx_web/endpoint.ex#L39) can be used as a reference","ref":"readme.html#note-on-phoenix-integration"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}